==> prize-center-api-1.0.9-20180525.083130-1-sources.jar: cn/com/duiba/prize/center/api/dto/winner/ActivityWinnerCarouselDto.java <==
package cn.com.duiba.prize.center.api.dto.winner;

import java.io.Serializable;
import java.util.Set;

import com.google.common.collect.ImmutableSet;

public class ActivityWinnerCarouselDto implements Serializable{
    /**
	 * 
	 */
	private static final long serialVersionUID = 1321230240096203130L;

	/**
     * 所有允许的来源类型
     */
    public static final Set<Integer> ALL_TYPE =  ImmutableSet.of(ActivityWinnerCarouselDto.TYPE_OPERATING_ACTIVITY, ActivityWinnerCarouselDto.TYPE_PLUGIN);

    /** 来源自入库活动 */
    public static final int TYPE_OPERATING_ACTIVITY = 0;

    /** 来源自插件活动 */
    public static final int TYPE_PLUGIN = 1;


    /** 主键id */
    private Long id;
    /** 活动id */
    private Long operatingActivityId;
    /** 活动类型 */
    private Integer operatingActivityType;
    /** 活动子订单id */
    private Long subOrderId;
    /** 奖项id */
    private Long optionId;
    /** 奖项类型 */
    private String optionType;
    /** 奖项名称 */
    private String optionName;
    /** 用户id */
    private Long consumerId;
    /** 应用Id */
    private Long appId;
    /** 活动来源 */
    private Integer originType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public Integer getOperatingActivityType() {
        return operatingActivityType;
    }

    public void setOperatingActivityType(Integer operatingActivityType) {
        this.operatingActivityType = operatingActivityType;
    }

    public Long getSubOrderId() {
        return subOrderId;
    }

    public void setSubOrderId(Long subOrderId) {
        this.subOrderId = subOrderId;
    }

    public Long getOptionId() {
        return optionId;
    }

    public void setOptionId(Long optionId) {
        this.optionId = optionId;
    }

    public String getOptionType() {
        return optionType;
    }

    public void setOptionType(String optionType) {
        this.optionType = optionType;
    }

    public String getOptionName() {
        return optionName;
    }

    public void setOptionName(String optionName) {
        this.optionName = optionName;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getOriginType() {
        return originType;
    }

    public void setOriginType(Integer originType) {
        this.originType = originType;
    }
}

==> prize-center-api-1.1.28-sources.jar: cn/com/duiba/prize/center/api/dto/winner/ActivityWinnerCarouselDto.java <==
package cn.com.duiba.prize.center.api.dto.winner;

import com.google.common.collect.ImmutableSet;

import java.io.Serializable;
import java.util.Set;

public class ActivityWinnerCarouselDto implements Serializable{
    /**
	 * 
	 */
	private static final long serialVersionUID = 1321230240096203130L;

	/**
     * 所有允许的来源类型
     */
    public static final Set<Integer> ALL_TYPE =  ImmutableSet.of(ActivityWinnerCarouselDto.TYPE_OPERATING_ACTIVITY,
            ActivityWinnerCarouselDto.TYPE_PLUGIN,
            ActivityWinnerCarouselDto.TYPE_CLCARD
            );

    /** 来源自入库活动 */
    public static final int TYPE_OPERATING_ACTIVITY = 0;

    /** 来源自插件活动 */
    public static final int TYPE_PLUGIN = 1;

    /** 来源自集卡 */
    public static final int TYPE_CLCARD = 2;


    /** 主键id */
    private Long id;
    /** 活动id */
    private Long operatingActivityId;
    /** 活动类型 */
    private Integer operatingActivityType;
    /** 活动子订单id */
    private Long subOrderId;
    /** 奖项id */
    private Long optionId;
    /** 奖项类型 */
    private String optionType;
    /** 奖项名称 */
    private String optionName;
    /** 用户id */
    private Long consumerId;
    /** 应用Id */
    private Long appId;
    /** 活动来源 */
    private Integer originType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public Integer getOperatingActivityType() {
        return operatingActivityType;
    }

    public void setOperatingActivityType(Integer operatingActivityType) {
        this.operatingActivityType = operatingActivityType;
    }

    public Long getSubOrderId() {
        return subOrderId;
    }

    public void setSubOrderId(Long subOrderId) {
        this.subOrderId = subOrderId;
    }

    public Long getOptionId() {
        return optionId;
    }

    public void setOptionId(Long optionId) {
        this.optionId = optionId;
    }

    public String getOptionType() {
        return optionType;
    }

    public void setOptionType(String optionType) {
        this.optionType = optionType;
    }

    public String getOptionName() {
        return optionName;
    }

    public void setOptionName(String optionName) {
        this.optionName = optionName;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getOriginType() {
        return originType;
    }

    public void setOriginType(Integer originType) {
        this.originType = originType;
    }
}
